.. cooltools documentation master file, created by
   sphinx-quickstart on Wed Jun 12 16:42:43 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Cooltools
=========

The tools for your *.cool*\ s


.. toctree::
   :maxdepth: 3
   :caption: Contents

   installation
   cli
   cooltools


.. toctree::
   :maxdepth: 2
   :caption: Tutorials

   ./notebooks/01_scaling-curves.ipynb
   ./notebooks/02_expected.ipynb
   ./notebooks/03_eigendecomposition.ipynb
   ./notebooks/04_saddle-plots.ipynb
   ./notebooks/05_insulation-score.ipynb
   ./notebooks/06_snipping-pileups.ipynb
   ./notebooks/07_pileups2.ipynb
   ./notebooks/08_dot-calling-internals.ipynb


.. toctree::
   :maxdepth: 1
   :caption: News
   
   releases



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
